@@ -1,4 +1,4 @@
-package At 0.06 {
+package At 0.07 {
     use v5.38;
     no warnings 'experimental::class', 'experimental::builtin', 'experimental::for_list';    # Be quiet.
     use feature 'class';
@@ -12,7 +12,13 @@ package At 0.06 {
     #~ |------3-33-----------------------------|
     #~ |-5-55------4-44-5-55----353--3-33-/1~--|
     #~ |---------------------335---33----------|
-    class At 1.00 {
+    class At {
+
+        sub resume ( $class, %config ) {    # store $at->http->session->_raw and restore it here
+            my $at = $class->new();
+            $at->http->set_session( \%config );
+            $at;
+        }
         field $http //= Mojo::UserAgent->can('start') ? At::UserAgent::Mojo->new() : At::UserAgent::Tiny->new();
         method http {$http}
         field $host : param = ();
@@ -20,14 +26,23 @@ package At 0.06 {
         field $identifier : param //= ();
         field $password : param   //= ();
         #
-        field $did : param = ();    # do not allow arg to new
+        field $did : param = ();            # do not allow arg to new
         method did {$did}
+
+        # Allow session restoration
+        field $accessJwt : param  //= ();
+        field $refreshJwt : param //= ();
         #
         method host {
             return $host if defined $host;
             use Carp qw[confess];
             confess 'You must provide a host or perhaps you wanted At::Bluesky';
         }
+
+        method session() {
+            return unless defined $http && defined $http->session;
+            $http->session->_raw;
+        }
         ## Internals
         sub _now {
             At::Protocol::Timestamp->new( timestamp => time );
@@ -37,10 +52,22 @@ package At 0.06 {
             if ( defined $host ) {
                 $host = 'https://' . $host unless $host =~ /^https?:/;
                 $host = URI->new($host)    unless builtin::blessed $host;
-                if ( defined $identifier && defined $password ) {    # auto-login
+                if ( defined $accessJwt && defined $refreshJwt && defined $did ) {
+                    $http->set_session( { accessJwt => $accessJwt, refreshJwt => $refreshJwt, did => $did } );
+                    $did = At::Protocol::DID->new( uri => $did );
+                }
+                elsif ( defined $identifier && defined $password ) {    # auto-login
                     my $session = $self->server_createSession( $identifier, $password );
-                    $http->set_session($session);
-                    $did = At::Protocol::DID->new( uri => $http->session->did->_raw );
+                    if ( defined $session->{accessJwt} ) {
+                        $http->set_session($session);
+                        $did = At::Protocol::DID->new( uri => $http->session->did->_raw );
+                    }
+                    else {
+                        use Carp qw[carp];
+                        carp 'Error creating session' . ( defined $session->{message} ? ': ' . $session->{message} : '' );
+
+                        #~ undef $self;
+                    }
                 }
             }
         }
@@ -48,6 +75,21 @@ package At 0.06 {
         #~ class At::Lexicon::AtProto::Admin
         {
 
+            method admin_createCommunicationTemplate ( $name, $subject, $contentMarkdown, $createdBy //= () ) {
+                $self->http->session // Carp::confess 'requires an authenticated client';
+                my $res = $self->http->post(
+                    sprintf( '%s/xrpc/%s', $self->host, 'com.atproto.admin.createCommunicationTemplate' ),
+                    {   content => +{
+                            name            => $name,
+                            subject         => $subject,
+                            contentMarkdown => $contentMarkdown,
+                            defined $createdBy ? ( createdBy => builtin::blessed $createdBy ? $createdBy->_raw : $createdBy ) : ()
+                        }
+                    }
+                );
+                $res->{success};
+            }
+
             method admin_deleteAccount ($did) {
                 $self->http->session // Carp::confess 'requires an authenticated client';
                 my $res
@@ -55,6 +97,13 @@ package At 0.06 {
                 $res->{success};
             }
 
+            method admin_deleteCommunicationTemplate ($id) {
+                $self->http->session // Carp::confess 'requires an authenticated client';
+                my $res = $self->http->post( sprintf( '%s/xrpc/%s', $self->host, 'com.atproto.admin.deleteCommunicationTemplate' ),
+                    { content => +{ id => $id } } );
+                $res->{success};
+            }
+
             method admin_disableAccountInvites ( $account, $note //= () ) {
                 $self->http->session // Carp::confess 'requires an authenticated client';
                 my $res = $self->http->post(
@@ -169,6 +218,15 @@ package At 0.06 {
                 $res;
             }
 
+            method admin_listCommunicationTemplates ( ) {
+                $self->http->session // Carp::confess 'requires an authenticated client';
+                my $res = $self->http->get( sprintf( '%s/xrpc/%s', $self->host, 'com.atproto.admin.listCommunicationTemplates' ) );
+                $res->{communicationTemplates}
+                    = [ map { $_ = At::Lexicon::com::atproto::admin::communicationTemplateView->new(%$_) } @{ $res->{communicationTemplates} } ]
+                    if defined $res->{communicationTemplates};
+                $res;
+            }
+
             method admin_queryModerationEvents (
                 $types                 //= (),
                 $createdBy             //= (),
@@ -295,12 +353,34 @@ package At 0.06 {
 
             method admin_updateAccountHandle ( $did, $handle ) {
                 $self->http->session // Carp::confess 'requires an authenticated client';
-                $did = At::Protocol::DID->new( uri => $did ) if defined $did && !builtin::blessed $did;
+                $did = At::Protocol::DID->new( uri => $did ) unless builtin::blessed $did;
                 my $res = $self->http->post( sprintf( '%s/xrpc/%s', $self->host, 'com.atproto.admin.updateAccountHandle' ),
                     { content => +{ did => $did->_raw, handle => $handle } } );
                 $res->{success};
             }
 
+            method admin_updateCommunicationTemplate (
+                $id,
+                $name            //= (),
+                $contentMarkdown //= (),
+                $subject         //= (),
+                $updatedBy       //= (),
+                $disabled        //= ()
+            ) {
+                $self->http->session // Carp::confess 'requires an authenticated client';
+                $updatedBy = At::Protocol::DID->new( uri => $did ) if defined $updatedBy && !builtin::blessed $updatedBy;
+                my $res = $self->http->post(
+                    sprintf( '%s/xrpc/%s', $self->host, 'com.atproto.admin.updateCommunicationTemplate' ),
+                    {   content => +{
+                            id => $id,
+                            defined $name      ? ( name      => $name ) : (), defined $contentMarkdown ? ( contentMarkdown => $contentMarkdown ) : (),
+                            defined $updatedBy ? ( updatedBy => $updatedBy->_raw ) : (), defined $disabled ? ( disabled => \!!$disabled )        : ()
+                        }
+                    }
+                );
+                $res->{success};
+            }
+
             method admin_updateSubjectStatus ( $subject, $takedown //= () ) {
                 $self->http->session // Carp::confess 'requires an authenticated client';
                 $subject  = At::_topkg( $subject->{'$type'} )->new(%$subject)        if !builtin::blessed $subject && defined $subject->{'$type'};
@@ -927,16 +1007,30 @@ package At 0.06 {
             field $didDoc : param         = ();    # spec says 'unknown' so I'm just gonna ignore it for now even with the dump
             field $email : param          = ();
             field $emailConfirmed : param = ();
-            field $handle : param;
+            field $handle : param         = ();
             field $refreshJwt : param;
 
             # waiting for perlclass to implement accessors with :reader
-            method accessJwt {$accessJwt}
-            method did       {$did}
+            method accessJwt  {$accessJwt}
+            method did        {$did}
+            method refreshJwt {$refreshJwt}
+            method handle     {$handle}
             #
             ADJUST {
                 $did            = At::Protocol::DID->new( uri => $did ) unless builtin::blessed $did;
-                $emailConfirmed = !!$emailConfirmed if defined $emailConfirmed;
+                $handle         = At::Protocol::Handle->new( id => $handle ) if defined $handle && !builtin::blessed $handle;
+                $emailConfirmed = !!$emailConfirmed                          if defined $emailConfirmed;
+            }
+
+            # This could be used as part of a session resume system
+            method _raw {
+                +{  accessJwt => $accessJwt,
+                    did       => $did->_raw,
+                    defined $didDoc ? ( didDoc => $didDoc ) : (), defined $email ? ( email => $email ) : (),
+                    defined $emailConfirmed ? ( emailConfirmed => \!!$emailConfirmed ) : (),
+                    refreshJwt => $refreshJwt,
+                    defined $handle ? ( handle => $handle->_raw ) : ()
+                };
             }
         }
 
@@ -1157,7 +1251,7 @@ The API attempts to follow the layout of the underlying protocol so changes to t
 
 Creates an AT client and initiates an authentication session.
 
-    my $self = At->new( host => 'https://bsky.social' );
+    my $at = At->new( host => 'https://bsky.social' );
 
 Expected parameters include:
 
@@ -1170,6 +1264,46 @@ want C<At::Bluesky-E<gt>new(...)> because that client comes with all the bits th
 
 =back
 
+=head2 C<resume( ... )>
+
+Resumes an authenticated session.
+
+    my $at = At->resume( $session );
+
+Expected parameters include:
+
+=over
+
+=item C<session> - required
+
+=back
+
+=head2 C<session( )>
+
+Returns data which may be used to resume an authenticated session.
+
+    my $restore = $at->session;
+
+Note that this data is subject to change in line with the AT protocol.
+
+=head2 C<admin_deleteCommunicationTemplate( ... )>
+
+    $at->admin_deleteCommunicationTemplate( 99999 );
+
+Delete a communication template.
+
+Expected parameters include:
+
+=over
+
+=item C<id> - required
+
+ID of the template.
+
+=back
+
+Returns a true value on success.
+
 =head2 C<admin_disableAccountInvites( ... )>
 
 Disable an account from receiving new invite codes, but does not invalidate existing codes.
@@ -1206,6 +1340,36 @@ List of account DIDs.
 
 =back
 
+=head2 C<admin_createCommunicationTemplate( ... )>
+
+    $at->admin_createCommunicationTemplate( 'warning_1', 'Initial Warning for [...]', 'You are being alerted [...]' );
+
+Administrative action to create a new, re-usable communication (email for now) template.
+
+Expected parameters include:
+
+=over
+
+=item C<name> - required
+
+Name of the template.
+
+=item C<subject> - required
+
+Subject of the message, used in emails.
+
+=item C<contentMarkdown> - required
+
+Content of the template, markdown supported, can contain variable placeholders.
+
+=item C<createdBy>
+
+DID of the user who is creating the template.
+
+=back
+
+Returns a true value on success.
+
 =head2 C<admin_deleteAccount( ... )>
 
     $at->admin_deleteAccount( 'did://...' );
@@ -1222,26 +1386,6 @@ Expected parameters include:
 
 Returns a true value on success.
 
-=head2 C<admin_disableAccountInvites( ..., [...] )>
-
-    $at->admin_disableAccountInvites( 'did://...' );
-
-Disable an account from receiving new invite codes, but does not invalidate existing codes.
-
-Expected parameters include:
-
-=over
-
-=item C<account> - required
-
-=item C<note>
-
-Optional reason for disabled invites.
-
-=back
-
-Returns a true value on success.
-
 =head2 C<admin_emitModerationEvent( ..., [...] )>
 
     $at->admin_emitModerationEvent( ... );
@@ -1411,6 +1555,15 @@ Expected parameters include:
 Returns a subject and, optionally, the takedown reason as a new C<At::Lexicon::com::atproto::admin::statusAttr> object
 on success.
 
+=head2 C<admin_listCommunicationTemplates( )>
+
+    $at->admin_listCommunicationTemplates( );
+
+Get list of all communication templates.
+
+Returns a list of communicationTemplates as new C<At::Lexicon::com::atproto::admin::communicationTemplateView> objects
+on success.
+
 =head2 C<admin_queryModerationEvents( [...] )>
 
     $at->admin_queryModerationEvents( 'did:...' );
@@ -1603,6 +1756,45 @@ Expected parameters include:
 
 Returns a true value on success.
 
+=head2 C<admin_updateCommunicationTemplate( ... )>
+
+    $at->admin_updateCommunicationTemplate( 999999, 'warning_1', 'First Warning for [...]' );
+
+Administrative action to update an existing communication template. Allows passing partial fields to patch specific
+fields only.
+
+Expected parameters include:
+
+=over
+
+=item C<id> - required
+
+ID of the template to be updated.
+
+=item C<name>
+
+Name of the template.
+
+=item C<contentMarkdown>
+
+Content of the template, markdown supported, can contain variable placeholders.
+
+=item C<subject>
+
+Subject of the message, used in emails.
+
+=item C<updatedBy>
+
+DID of the user who is updating the template.
+
+=item C<disabled>
+
+Boolean.
+
+=back
+
+Returns a true value on success.
+
 =head2 C<admin_updateSubjectStatus( ..., [...] )>
 
     $at->admin_updateSubjectStatus( ... );
@@ -2710,7 +2902,7 @@ Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 =begin stopwords
 
-didDoc cids cid websocket
+didDoc cids cid websocket emails communicationTemplates
 
 =end stopwords
 
